==> tasks-v1.8.8.zip: tasks/messages/sk/base.php <==
<?php

return [
    '1 Day before' => '1 deň vopred',
    '1 Month before' => '1 mesiac predtým',
    '1 Week before' => '1 týždeň predtým',
    '2 Days before' => '2 dni predtým',
    '2 Weeks before' => '2 týždne predtým',
    '3 Weeks before' => '3 týždne predtým',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Priradení používatelia</strong> môžu túto úlohu spracovať.',
    '<strong>Confirm</strong> task deletion' => '<strong>Potvrdiť</strong> odstránenie úlohy',
    '<strong>Create</strong> task list' => '<strong>Vytvoriť</strong> zoznam úloh',
    '<strong>Edit</strong> task' => '<strong>Upraviť</strong> úlohu',
    '<strong>Edit</strong> task list' => '<strong>Upraviť</strong> zoznam úloh',
    '<strong>New</strong> Task' => '<strong>Nová</strong> úloha',
    '<strong>Task</strong> Overview' => 'Prehľad <strong>Úlohy</strong>',
    '<strong>Tasks</strong>' => '<strong>Úlohy</strong>',
    '<strong>Tasks</strong> module configuration' => 'Konfigurácia modulu <strong>Úlohy</strong>',
    '<strong>Your</strong> tasks' => '<strong>Vaše</strong> úlohy',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Miniaplikácia je prvok pridaný na bočný panel prúdu. V tomto prípade poskytuje používateľom krátky prehľad ich úloh.',
    'Accept Task' => 'Prijmite úlohu',
    'Add Deadline to space calendar' => 'Pridať Konečný termín do kalendára Priestoru',
    'Add checkpoint...' => 'Pridať kontrolný bod...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Pridajte k úlohe kontrolné body, aby ste zvýraznili jednotlivé kroky potrebné na jej dokončenie.',
    'Add entry to main navigation' => 'Pridajte záznam do hlavnej navigácie',
    'Add reminder' => 'Pridať pripomienku',
    'Add responsible users' => 'Pridajte zodpovedných používateľov',
    'Add schedule to the space calendar' => 'Pridajte plán do kalendára Priestoru',
    'Add task' => 'Pridať úlohu',
    'Add to space calendar' => 'Pridať do kalendára Priestoru',
    'Additional options' => 'Ďalšie možnosti',
    'All Day' => 'Celý deň',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Umožňuje užívateľovi vytvárať nové úlohy, užívateľ bude môcť iba upravovať a mazať vlastné úlohy',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Umožňuje používateľovi vytvárať, mazať a upravovať úlohy a zoznamy a tiež triediť úlohy a zoznamy',
    'Allows the user to process unassigned tasks' => 'Umožňuje používateľovi spracovať nepriradené úlohy',
    'Already requested' => 'Už vyžiadané',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Na tejto úlohe môže pracovať každý používateľ s povolením „Spracovať nepriradené úlohy“.',
    'Anyone can work on this task!' => 'Na tejto úlohe môže pracovať každý!',
    'Assign myself' => 'Prideliť seba',
    'Assign users' => 'Priraďte používateľov',
    'Assigned' => 'Priradených',
    'Assigned users' => 'Priradení používatelia',
    'Assignment' => 'Priradenie',
    'Assignments:' => 'Priradenia:',
    'At least 1 Hour before' => 'Minimálne 1 hodinu vopred',
    'At least 2 Hours before' => 'Minimálne 2 hodiny vopred',
    'Attachments' => 'Prílohy',
    'Begin Task' => 'Začať úlohu',
    'Checklist Items' => 'Položky kontrolného zoznamu',
    'Checklist:' => 'Kontrolný zoznam:',
    'Checkpoints' => 'Kontrolné body',
    'Choose if you want the module to appear in the main navigation.' => 'Vyberte, či chcete, aby sa modul zobrazoval v hlavnej navigácii.',
    'Close' => 'Zatvoriť',
    'Color' => 'Farba',
    'Completed' => 'Dokončené',
    'Completed lists' => 'Dokončené zoznamy',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Nakonfigurujte modul Úlohy tak, aby vyhovoval vašim špecifickým požiadavkám a potrebám. Môžete definovať individuálne nastavenia a napríklad rozhodnúť, či sa zobrazí miniaplikácia.',
    'Continue Review' => 'Pokračovať v Posudku',
    'Create tasks' => 'Vytvoriť úlohy',
    'Created by me' => 'Vytvorené mnou',
    'Date' => 'Dátum',
    'Deadline at' => 'Konečný termín v',
    'Deadline: ' => 'Konečný termín:',
    'Delete' => 'Odstrániť',
    'Delete list' => 'Odstrániť zoznam',
    'Description' => 'Popis',
    'Do not remind' => 'Nepripomínať',
    'Do you really want to delete this task?' => 'Naozaj chcete odstrániť túto úlohu?',
    'Don\'t add to calendar' => 'Nepridávať do kalendára',
    'Drag entry' => 'Potiahnite položku',
    'Edit' => 'Upraviť',
    'Edit item (empty field will be removed)...' => 'Upraviť položku (prázdne pole bude odstránené)...',
    'Edit list' => 'Upraviť zoznam',
    'End' => 'Koniec',
    'End Date' => 'Dátum ukončenia',
    'End Time' => 'Čas ukončenia',
    'End date' => 'Dátum ukončenia',
    'End time must be after start time!' => 'Čas ukončenia musí byť neskorší ako čas začiatku!',
    'Extend deadline request' => 'Žiadosť o predĺženie termínu',
    'Filter' => 'Filter',
    'Filter by status' => 'Filtrovať podľa stavu',
    'Filter by title' => 'Filtrovať podľa názvu',
    'Filter tasks' => 'Filtrovať úlohy',
    'Finish Task' => 'Dokončiť úlohu',
    'General' => 'Všeobecné',
    'General Settings' => 'Všeobecné nastavenia',
    'Hide this list once all tasks are completed' => 'Po dokončení všetkých úloh tento zoznam skryť',
    'I\'m assigned' => 'Som zadaný',
    'I\'m responsible' => 'Som zodpovedný',
    'If empty any user can complete the task.' => 'Ak je prázdny, môže úlohu dokončiť ktorýkoľvek používateľ.',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Ak nie je vybratý žiadny priradený používateľ, môže úlohu spracovať každý člen priestoru s povolením na spracovanie nepriradených úloh.',
    'In Progress' => 'Prebieha',
    'In Review' => 'V Posúdení',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Ak je možnosť kontroly aktívna, <strong>zodpovedný používateľ</strong> bude musieť túto úlohu pred dokončením skontrolovať a buď odmietnuť alebo potvrdiť.',
    'Invalid task list selection.' => 'Neplatný výber zoznamu úloh.',
    'Let Task Review' => 'Nechajte si skontrolovať úlohu',
    'Main Navigation' => 'Hlavná navigácia',
    'Manage tasks' => 'Spravovať úlohy',
    'Maximum number of entries in widget' => 'Maximálny počet záznamov v miniaplikácii',
    'Module Widget' => 'Miniaplikácia Modulu',
    'New list or search' => 'Nový zoznam alebo vyhľadávanie',
    'No Scheduling set for this Task' => 'Pre túto úlohu nie je nastavené žiadne plánovanie',
    'No pending tasks found' => 'Nenašli sa žiadne čakajúce úlohy',
    'No results found for the given filter.' => 'Pre daný filter sa nenašli žiadne výsledky.',
    'Open Task' => 'Otvoriť Úlohu',
    'Other Tasks' => 'Iné úlohy',
    'Overdue' => 'Po termíne',
    'Overview' => 'Prehľad',
    'Parent Task' => 'Rodičovská úloha',
    'Pending' => 'Čaká na spracovanie',
    'Pending Review' => 'Čaká na kontrolu',
    'Process unassigned tasks' => 'Spracujte nepriradené úlohy',
    'Ready For Review' => 'Pripravené na kontrolu',
    'Receive Notifications for Task Reminder.' => 'Prijímať upozornenia na pripomenutie úloh.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Prijímať upozornenia na úlohy (aktualizácie termínu, zmeny stavu ...).',
    'Reject Task' => 'Odmietnuť úlohu',
    'Remind Mode' => 'Režim pripomenutia',
    'Reminder' => 'Pripomenutie',
    'Reminder sent' => 'Pripomienka bola odoslaná',
    'Reminders' => 'Pripomienky',
    'Request extension' => 'Požiadať o predĺženie',
    'Request sent' => 'Žiadosť odoslaná',
    'Reset Task' => 'Obnoviť úlohu',
    'Responsible' => 'Zodpovedný',
    'Responsible users' => 'Zodpovední používatelia',
    'Review by responsible user required' => 'Vyžaduje sa kontrola zodpovedným používateľom',
    'Scheduling' => 'Plánovanie',
    'Show widget in Spaces' => 'Zobraziť miniaplikáciu v Priestore',
    'Show widget on Dashboard' => 'Zobraziť miniaplikáciu na Nástenke',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Zobraziť {count} ďalších dokončených {countTasks,plural,=1{úloha} =2{úlohy} =3{úlohy} =4{úlohy} other{úloh}}',
    'Sort Order' => 'Poradie Zoradenia',
    'Sort order' => 'Poradie zoradenia',
    'Spaces' => 'Priestory',
    'Start' => 'Štart',
    'Start Date' => 'Dátum Začiatku',
    'Start Time' => 'Čas Začiatku',
    'Start date' => 'Dátum začiatku',
    'Starting at' => 'Začiatok v',
    'Status' => 'Stav',
    'Task' => 'Úloha',
    'Task List' => 'Zoznam úloh',
    'Task Users have been notified' => 'Používatelia Úlohy boli upozornení',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Úloha {task} v priestore {spaceName} končí o {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Úloha {task} v priestore {spaceName} začína o {dateTime}.',
    'Tasks' => 'Úlohy',
    'Tasks: Reminder' => 'Úlohy: Pripomienka',
    'This task can only be processed by assigned and responsible users.' => 'Túto úlohu môžu spracovať iba pridelení a zodpovední používatelia.',
    'This task requires to be reviewed by a responsible' => 'Táto úloha si vyžaduje, aby ju skontroloval zodpovedný používateľ',
    'Time Zone' => 'Časová zóna',
    'Title' => 'Názov',
    'Title and Color' => 'Názov a farba',
    'Title of your task list' => 'Názov vášho zoznamu úloh',
    'Today' => 'Dnes',
    'Unsorted' => 'Netriedené',
    'View Online' => 'Zobraziť Online',
    'You are assigned!' => 'Si zadaný!',
    'You are responsible!' => 'Vy ste zodpovedný!',
    'You have insufficient permissions to perform that operation!' => 'Nemáte dostatočné povolenia na vykonanie tejto operácie!',
    'Your Reminder for task {task}' => 'Vaša pripomienka úlohy {task}',
    'ending Review' => 'koniec Posudku',
    'view all' => 'zobraziť všetky',
    '{count,plural,=1{# day} other{# days}} remaining' => 'Zostáva {count,plural,=1{# deň} =2{# dni} =3{# dni} =4{# dni} other{# dní}}',
    '{displayName} is assigned to this task' => 'K tejto úlohe je priradený {displayName}',
    '{displayName} is responsible for this task' => 'Za túto úlohu je zodpovedný {displayName}',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} vás priradil ako zodpovednú osobu v úlohe {task} z priestoru {spaceName}',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} vám priradil úlohu {task} v priestore {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} dokončil úlohu {task} v priestore {spaceName}.',
    '{userName} completed task {task}.' => '{userName} dokončil úlohu {task}.',
    '{userName} finished task {task}.' => '{userName} dokončil úlohu {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} zmenil termín pre úlohu {task} v priestore {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} znova otvoril úlohu {task} v priestore {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} odmietol úlohu {task} v priestore {spaceName} ako nedokončenú.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => 'Používateľ {userName} označil úlohu {task} v priestore {spaceName} za dokončenú.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} požaduje predĺženie termínu pre úlohu {task} v priestore {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} vás žiada o kontrolu úlohy {task} v priestore {spaceName}.',
    '{userName} reset task {task}.' => '{userName} resetoval úlohu {task}.',
    '{userName} reviewed task {task}.' => '{userName} skontroloval úlohu {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} začal pracovať na úlohe {task} v priestore {spaceName}.',
    '{userName} works on task {task}.' => '{userName} pracuje na úlohe {task}.',
    'Task content ID' => '',
];

==> tasks-v1.9.1.zip: tasks/messages/sk/base.php <==
<?php

return [
    '1 Day before' => '1 deň vopred',
    '1 Month before' => '1 mesiac predtým',
    '1 Week before' => '1 týždeň predtým',
    '2 Days before' => '2 dni predtým',
    '2 Weeks before' => '2 týždne predtým',
    '3 Weeks before' => '3 týždne predtým',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Priradení používatelia</strong> môžu túto úlohu spracovať.',
    '<strong>Confirm</strong> task deletion' => '<strong>Potvrdiť</strong> odstránenie úlohy',
    '<strong>Create</strong> task list' => '<strong>Vytvoriť</strong> zoznam úloh',
    '<strong>Edit</strong> task' => '<strong>Upraviť</strong> úlohu',
    '<strong>Edit</strong> task list' => '<strong>Upraviť</strong> zoznam úloh',
    '<strong>New</strong> Task' => '<strong>Nová</strong> úloha',
    '<strong>Task</strong> Overview' => 'Prehľad <strong>Úlohy</strong>',
    '<strong>Tasks</strong>' => '<strong>Úlohy</strong>',
    '<strong>Tasks</strong> module configuration' => 'Konfigurácia modulu <strong>Úlohy</strong>',
    '<strong>Your</strong> tasks' => '<strong>Vaše</strong> úlohy',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Miniaplikácia je prvok pridaný na bočný panel prúdu. V tomto prípade poskytuje používateľom krátky prehľad ich úloh.',
    'Accept Task' => 'Prijmite úlohu',
    'Add Deadline to space calendar' => 'Pridať Konečný termín do kalendára Priestoru',
    'Add checkpoint...' => 'Pridať kontrolný bod...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Pridajte k úlohe kontrolné body, aby ste zvýraznili jednotlivé kroky potrebné na jej dokončenie.',
    'Add entry to main navigation' => 'Pridajte záznam do hlavnej navigácie',
    'Add reminder' => 'Pridať pripomienku',
    'Add responsible users' => 'Pridajte zodpovedných používateľov',
    'Add schedule to the space calendar' => 'Pridajte plán do kalendára Priestoru',
    'Add task' => 'Pridať úlohu',
    'Add to space calendar' => 'Pridať do kalendára Priestoru',
    'Additional options' => 'Ďalšie možnosti',
    'All Day' => 'Celý deň',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Umožňuje užívateľovi vytvárať nové úlohy, užívateľ bude môcť iba upravovať a mazať vlastné úlohy',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Umožňuje používateľovi vytvárať, mazať a upravovať úlohy a zoznamy a tiež triediť úlohy a zoznamy',
    'Allows the user to process unassigned tasks' => 'Umožňuje používateľovi spracovať nepriradené úlohy',
    'Already requested' => 'Už vyžiadané',
    'Assign myself' => 'Prideliť seba',
    'Assign users' => 'Priraďte používateľov',
    'Assigned users' => 'Priradení používatelia',
    'Assignment' => 'Priradenie',
    'At least 1 Hour before' => 'Minimálne 1 hodinu vopred',
    'At least 2 Hours before' => 'Minimálne 2 hodiny vopred',
    'Attachments' => 'Prílohy',
    'Begin Task' => 'Začať úlohu',
    'Checklist Items' => 'Položky kontrolného zoznamu',
    'Checklist:' => 'Kontrolný zoznam:',
    'Checkpoints' => 'Kontrolné body',
    'Choose if you want the module to appear in the main navigation.' => 'Vyberte, či chcete, aby sa modul zobrazoval v hlavnej navigácii.',
    'Close' => 'Zatvoriť',
    'Color' => 'Farba',
    'Completed' => 'Dokončené',
    'Completed lists' => 'Dokončené zoznamy',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Nakonfigurujte modul Úlohy tak, aby vyhovoval vašim špecifickým požiadavkám a potrebám. Môžete definovať individuálne nastavenia a napríklad rozhodnúť, či sa zobrazí miniaplikácia.',
    'Continue Review' => 'Pokračovať v Posudku',
    'Create tasks' => 'Vytvoriť úlohy',
    'Created by me' => 'Vytvorené mnou',
    'Date' => 'Dátum',
    'Deadline: ' => 'Konečný termín:',
    'Delete' => 'Odstrániť',
    'Delete list' => 'Odstrániť zoznam',
    'Description' => 'Popis',
    'Do not remind' => 'Nepripomínať',
    'Do you really want to delete this task?' => 'Naozaj chcete odstrániť túto úlohu?',
    'Don\'t add to calendar' => 'Nepridávať do kalendára',
    'Edit' => 'Upraviť',
    'Edit item (empty field will be removed)...' => 'Upraviť položku (prázdne pole bude odstránené)...',
    'Edit list' => 'Upraviť zoznam',
    'End' => 'Koniec',
    'End Date' => 'Dátum ukončenia',
    'End Time' => 'Čas ukončenia',
    'End date' => 'Dátum ukončenia',
    'End time must be after start time!' => 'Čas ukončenia musí byť neskorší ako čas začiatku!',
    'Extend deadline request' => 'Žiadosť o predĺženie termínu',
    'Filter' => 'Filter',
    'Filter by status' => 'Filtrovať podľa stavu',
    'Filter by title' => 'Filtrovať podľa názvu',
    'Filter tasks' => 'Filtrovať úlohy',
    'Finish Task' => 'Dokončiť úlohu',
    'General' => 'Všeobecné',
    'General Settings' => 'Všeobecné nastavenia',
    'Hide this list once all tasks are completed' => 'Po dokončení všetkých úloh tento zoznam skryť',
    'I\'m assigned' => 'Som zadaný',
    'I\'m responsible' => 'Som zodpovedný',
    'If empty any user can complete the task.' => 'Ak je prázdny, môže úlohu dokončiť ktorýkoľvek používateľ.',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Ak nie je vybratý žiadny priradený používateľ, môže úlohu spracovať každý člen priestoru s povolením na spracovanie nepriradených úloh.',
    'In Progress' => 'Prebieha',
    'In Review' => 'V Posúdení',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Ak je možnosť kontroly aktívna, <strong>zodpovedný používateľ</strong> bude musieť túto úlohu pred dokončením skontrolovať a buď odmietnuť alebo potvrdiť.',
    'Invalid task list selection.' => 'Neplatný výber zoznamu úloh.',
    'Let Task Review' => 'Nechajte si skontrolovať úlohu',
    'Main Navigation' => 'Hlavná navigácia',
    'Manage tasks' => 'Spravovať úlohy',
    'Maximum number of entries in widget' => 'Maximálny počet záznamov v miniaplikácii',
    'Module Widget' => 'Miniaplikácia Modulu',
    'New list or search' => 'Nový zoznam alebo vyhľadávanie',
    'No Scheduling set for this Task' => 'Pre túto úlohu nie je nastavené žiadne plánovanie',
    'No pending tasks found' => 'Nenašli sa žiadne čakajúce úlohy',
    'No results found for the given filter.' => 'Pre daný filter sa nenašli žiadne výsledky.',
    'Open Task' => 'Otvoriť Úlohu',
    'Other Tasks' => 'Iné úlohy',
    'Overdue' => 'Po termíne',
    'Overview' => 'Prehľad',
    'Parent Task' => 'Rodičovská úloha',
    'Pending' => 'Čaká na spracovanie',
    'Pending Review' => 'Čaká na kontrolu',
    'Process unassigned tasks' => 'Spracujte nepriradené úlohy',
    'Ready For Review' => 'Pripravené na kontrolu',
    'Receive Notifications for Task Reminder.' => 'Prijímať upozornenia na pripomenutie úloh.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Prijímať upozornenia na úlohy (aktualizácie termínu, zmeny stavu ...).',
    'Reject Task' => 'Odmietnuť úlohu',
    'Remind Mode' => 'Režim pripomenutia',
    'Reminder' => 'Pripomenutie',
    'Reminder sent' => 'Pripomienka bola odoslaná',
    'Reminders' => 'Pripomienky',
    'Request extension' => 'Požiadať o predĺženie',
    'Request sent' => 'Žiadosť odoslaná',
    'Reset Task' => 'Obnoviť úlohu',
    'Responsible' => 'Zodpovedný',
    'Responsible users' => 'Zodpovední používatelia',
    'Review by responsible user required' => 'Vyžaduje sa kontrola zodpovedným používateľom',
    'Scheduling' => 'Plánovanie',
    'Show widget in Spaces' => 'Zobraziť miniaplikáciu v Priestore',
    'Show widget on Dashboard' => 'Zobraziť miniaplikáciu na Nástenke',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Zobraziť {count} ďalších dokončených {countTasks,plural,=1{úloha} =2{úlohy} =3{úlohy} =4{úlohy} other{úloh}}',
    'Sort Order' => 'Poradie Zoradenia',
    'Sort order' => 'Poradie zoradenia',
    'Spaces' => 'Priestory',
    'Start' => 'Štart',
    'Start Date' => 'Dátum Začiatku',
    'Start Time' => 'Čas Začiatku',
    'Start date' => 'Dátum začiatku',
    'Starting at' => 'Začiatok v',
    'Status' => 'Stav',
    'Task' => 'Úloha',
    'Task List' => 'Zoznam úloh',
    'Task Users have been notified' => 'Používatelia Úlohy boli upozornení',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Úloha {task} v priestore {spaceName} končí o {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Úloha {task} v priestore {spaceName} začína o {dateTime}.',
    'Tasks' => 'Úlohy',
    'Tasks: Reminder' => 'Úlohy: Pripomienka',
    'This task requires to be reviewed by a responsible' => 'Táto úloha si vyžaduje, aby ju skontroloval zodpovedný používateľ',
    'Time Zone' => 'Časová zóna',
    'Title' => 'Názov',
    'Title and Color' => 'Názov a farba',
    'Title of your task list' => 'Názov vášho zoznamu úloh',
    'Today' => 'Dnes',
    'Unsorted' => 'Netriedené',
    'View Online' => 'Zobraziť Online',
    'You have insufficient permissions to perform that operation!' => 'Nemáte dostatočné povolenia na vykonanie tejto operácie!',
    'Your Reminder for task {task}' => 'Vaša pripomienka úlohy {task}',
    'view all' => 'zobraziť všetky',
    '{count,plural,=1{# day} other{# days}} remaining' => 'Zostáva {count,plural,=1{# deň} =2{# dni} =3{# dni} =4{# dni} other{# dní}}',
    '{displayName} is assigned to this task' => 'K tejto úlohe je priradený {displayName}',
    '{displayName} is responsible for this task' => 'Za túto úlohu je zodpovedný {displayName}',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} vás priradil ako zodpovednú osobu v úlohe {task} z priestoru {spaceName}',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} vám priradil úlohu {task} v priestore {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} dokončil úlohu {task} v priestore {spaceName}.',
    '{userName} completed task {task}.' => '{userName} dokončil úlohu {task}.',
    '{userName} finished task {task}.' => '{userName} dokončil úlohu {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} zmenil termín pre úlohu {task} v priestore {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} znova otvoril úlohu {task} v priestore {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} odmietol úlohu {task} v priestore {spaceName} ako nedokončenú.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => 'Používateľ {userName} označil úlohu {task} v priestore {spaceName} za dokončenú.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} požaduje predĺženie termínu pre úlohu {task} v priestore {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} vás žiada o kontrolu úlohy {task} v priestore {spaceName}.',
    '{userName} reset task {task}.' => '{userName} resetoval úlohu {task}.',
    '{userName} reviewed task {task}.' => '{userName} skontroloval úlohu {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} začal pracovať na úlohe {task} v priestore {spaceName}.',
    '{userName} works on task {task}.' => '{userName} pracuje na úlohe {task}.',
    'Assignments' => '',
    'Deadline' => '',
    'ID' => '',
    'Request Review' => '',
    'Task content ID' => '',
    '{displayName} is task creator' => '',
];
